searchData={"items":[{"type":"extras","title":"Nerves Pack","doc":"# Nerves Pack\n\n[![Hex version](https://img.shields.io/hexpm/v/nerves_pack.svg \"Hex version\")](https://hex.pm/packages/nerves_pack)\n[![CircleCI](https://circleci.com/gh/nerves-project/nerves_pack.svg?style=svg)](https://circleci.com/gh/nerves-project/nerves_pack)\n\nA compilation of dependencies and default configuration for getting Nerves\nprojects up and running with minimal work.\n\nWhen added to your project, Nerves Pack brings in the following services and\nsupport libraries:\n\n* **Networking**, using [`VintageNet`](https://hex.pm/packages/vintage_net).\n* **mDNS**, via [`MdnsLite`](https://hex.pm/packages/mdns_lite).\n* **SSH**, via [`NervesSSH`](https://hex.pm/packages/nerves_ssh). Includes:\n  * regular SSH access\n  * firmware updates subsystem via [`SSHSubsystemFwup`](https://hex.pm/packages/ssh_subsystem_fwup)\n  * SFTP subsystem\n  * Ability to configure more subsystems as needed\n* **Time**, via [`NervesTime`](https://hex.pm/packages/nerves_time)\n* **Logging**, via [`RingLogger`](https://hex.pm/packages/ring_logger)\n* **MOTD**, via [`NervesMOTD`](https://hex.pm/packages/nerves_motd)\n\nNerves Pack only contains dependencies. There's no code in this library. Once\nyou find that you want to customize what's included in your project, just remove\nthe `:nerves_pack` dependency and add the dependencies you need.\n\nWhen updating old Nerves project, Nerves Pack is the new version of\n`nerves_init_gadget`. The main change will be moving your `:nerves_networking`\nconfiguration to VintageNet.","ref":"readme.html"},{"type":"extras","title":"Installation - Nerves Pack","doc":"```elixir\ndef deps do\n  [\n    {:nerves_pack, \"~> 0.4.1\"}\n  ]\nend\n```\n\nThis will start `NervesPack` and all its services with your application.\nHowever, since it controls the networking and SSH interface, it is recommended\nto use it with [`shoehorn`](https://github.com/nerves-project/shoehorn) to start\nit up separately so you still have access to your device in the event that the\nmain application fails. This can be done by adding `shoehorn` to your\n`config.exs`:\n\n```elixir\nconfig :shoehorn,\n  init: [:nerves_runtime, :nerves_pack],\n  app: Mix.Project.config()[:app]\n```","ref":"readme.html#installation"},{"type":"extras","title":"mDNS - Nerves Pack","doc":"mDNS is an protocol that makes it easier to find the IP addresses of Nerves\ndevices on a LAN. `nerves_pack` pulls in\n[`mdns_lite`](https://github.com/nerves-networking/mdns_lite) to help with this\nand the default Nerves new project generator adds a default configuration that\nlets you connect to your Nerves device via the names, `nerves.local` or\n`nerves-wxyz.local` where `wxyz` are part of the device's unique identifier.\nDevice identifers are device-specific and can be found by typing `hostname` at\nthe IEx prompt.\n\nIf you are converting a project to use `nerves_pack`, here's a starter\nconfiguration to paste into your config:\n\n```elixir\nconfig :mdns_lite,\n  # The `host` key specifies what hostnames mdns_lite advertises.  `:hostname`\n  # advertises the device's hostname.local. For the official Nerves systems, this\n  # is \"nerves-<4 digit serial#>.local\".  mdns_lite also advertises\n  # \"nerves.local\" for convenience. If more than one Nerves device is on the\n  # network, delete \"nerves\" from the list.\n\n  host: [:hostname, \"nerves\"],\n  ttl: 120,\n\n  # Advertise the following services over mDNS.\n  services: [\n    %{\n      protocol: \"ssh\",\n      transport: \"tcp\",\n      port: 22\n    },\n    %{\n      protocol: \"sftp-ssh\",\n      transport: \"tcp\",\n      port: 22\n    },\n    %{\n      protocol: \"epmd\",\n      transport: \"tcp\",\n      port: 4369\n    }\n  ]\n```","ref":"readme.html#mdns"},{"type":"extras","title":"SSH port - Nerves Pack","doc":"`nerves_pack` depends on\n[`nerves_ssh`](https://github.com/nerves-project/nerves_ssh). `nerves_ssh`\nstarts up an SSH server on port 22 (the default SSH port) that provides an IEx\nconsole, SFTP, and firmware update support. See the `nerves_ssh` documentation\nfor changing the configuration.\n\nBy default, the Nerves new project generator creates projects that include your\nSSH public key (from `~/.ssh/id_rsa`, etc.) in your `config.exs` under the\n`nerves_ssh` configuration. It is possible that your project has this\nconfiguration under the `nerves_firmware_ssh` key. If so, you will receive an\nerror directing you to update your configuration.\n\nThe use of SSH public keys lets you log into your Nerves devices, but no one\nelse.  See [the\ndocs](https://hexdocs.pm/nerves_firmware_ssh/readme.html#installation) for how\nto configure your keys). Usernames are ignored.\n\nConnect by running:\n\n```bash\nssh nerves.local\n```\n\nIf your computer has trouble with mDNS, you may need to replace `nerves.local`\nwith the device's IP address. This is more of an issue on Windows than Linux or\nOSX. See your router or use a port scanner like `nmap` to find the device.\n\nTo exit the SSH session, type `exit` or type the ssh escape sequence `~.` . (See\nthe [ssh man page](https://linux.die.net/man/1/ssh) for other escape sequences).\nTyping `Ctrl+D` or `logoff` at the IEx prompt to exit the session won't work.","ref":"readme.html#ssh-port"},{"type":"extras","title":"Erlang distribution - Nerves Pack","doc":"`nerves_pack` does not start Erlang distribution. Distribution is not hard to\nenable, but it requires some thought on node naming and security.\n\nErlang distribution requires that the hostname part of the device's node name be\nreachable from the computer that's trying to connect. Options include IP\naddresses, DNS names, mDNS names or names that you put in your `/etc/hosts`\nfile. Many Nerves users use mDNS names for simplicity, but they have\nlimitations. You may need to adjust the following script based on your\nenvironment.\n\nThe Nerves project generator configures\n[`mdns_lite`](https://github.com/pcmarks/mdns_lite) to advertise two hostnames:\n`nerves.local` and `nerves-1234.local`. The latter one is based on the serial\nnumber of the device. If you only have one Nerves device on the network, use\n`nerves.local`. But, if you have many devices, figure out each hostname\nfrom the device's serial number, either by using a mDNS discovery program or by\nlogging into a device via a serial console and typing `hostname` at the IEx\nprompt.\n\nThe following uses `nerves.local`, but substitute for the name that you want.\nRun this by `ssh`'ing into your Nerves device.\n\n```elixir\niex> System.cmd(\"epmd\", [\"-daemon\"])\n{\"\", 0}\niex> Node.start(:\"nerves@nerves.local\")\n{:ok, #PID<0.26318.2>}\niex(nerves@nerves.local)> Node.set_cookie(:my_secret_cookie)\ntrue\n```\n\nFor a programmatic implementation, see `:inet.gethostname/0` for constructing\na device-specific node name.\n\nNow that Erlang distribution is running, try to connect to the device on your\ncomputer.\n\n```bash\n$ iex --name me@0.0.0.0 --cookie my_secret_cookie --remsh nerves@nerves.local\nErlang/OTP 22 [erts-10.6.4] [source] [64-bit] [smp:32:32] [ds:32:32:10]\n[async-threads:1] [hipe]\n\nInteractive Elixir (1.9.4) - press Ctrl+C to exit (type h() ENTER for help)\niex(nerves@nerves.local)1> use Toolshed\nToolshed imported. Run h(Toolshed) for more info\n:ok\niex(nerves@nerves.local)2> cat \"/proc/cpuinfo\"\nprocessor       : 0\nmodel name      : ARMv6-compatible processor rev 7 (v6l)\nBogoMIPS        : 697.95\nFeatures        : half thumb fastmult vfp edsp java tls\nCPU implementer : 0x41\nCPU architecture: 7\nCPU variant     : 0x0\nCPU part        : 0xb76\nCPU revision    : 7\n\nHardware        : BCM2835\nRevision        : 9000c1\nSerial          : 00000000b27aa712\nModel           : Raspberry Pi Zero W Rev 1.1\n\niex(nerves@nerves.local)6>\n```","ref":"readme.html#erlang-distribution"},{"type":"extras","title":"Optional WiFi wizard setup - Nerves Pack","doc":"_When_ and _how_ to start the WiFi wizard is generally very dependent on your\nuse-case so it's recommended that you implement the startup logic on your own.\n\nSee the [`vintage_net_wizard` docs](https://hexdocs.pm/vintage_net_wizard) for\nmore information on use and configuration.","ref":"readme.html#optional-wifi-wizard-setup"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.7.1 - Changelog","doc":"* Changes\n  * Remove all dependency constraints. The libraries referenced by\n    `:nerves_pack` have dependency constraints that may be more complicated than\n    what can be expressed here, so delegate completely to them.","ref":"changelog.html#v0-7-1"},{"type":"extras","title":"v0.7.0 - Changelog","doc":"* Potentially Breaking Changes\n  * Bump minimums to Elixir >= 1.10 / OTP >= 23","ref":"changelog.html#v0-7-0"},{"type":"extras","title":"v0.6.0 - Changelog","doc":"* Potentially Breaking Changes\n  * Bump minimum Elixir to 1.9\n  * Force upgrades to vintage_net and mdns_lite","ref":"changelog.html#v0-6-0"},{"type":"extras","title":"v0.5.0 - Changelog","doc":"Add `:nerves_motd` to the dependency list so that it's easy for projects to add\na nice login greeting.","ref":"changelog.html#v0-5-0"},{"type":"extras","title":"v0.4.2 - Changelog","doc":"This allows `v0.10` of the `vintage_net*` libraries.\n\nAlso bumps some dependencies","ref":"changelog.html#v0-4-2"},{"type":"extras","title":"v0.4.1 - Changelog","doc":"Removes automatic `mdns_lite` setup and shifts this project to be dependency\nand documentation driven as an example of basic Nerves project setup.\n\n* Fixes\n  * Fixes a dependency ordering issue for Elixir 1.11. See https://github.com/nerves-project/nerves_pack/pull/42","ref":"changelog.html#v0-4-1"},{"type":"extras","title":"v0.4.0 - Changelog","doc":"This refactors SSH support to its own library so that projects not using\n`nerves_pack` don't have to copy/paste the SSH code. `nerves_ssh` also\nhas several improvements to SSH support that will be easier to maintain\nin a standalone project.\n\nThis also brings in the switch from `nerves_firmware_ssh` to\n`ssh_subsystem_fwup` which moves firmware updates from port 8989 to an\nSSH subsystem on port 22. This is a breaking change for scripts that\nload firmware to Nerves devices via SSH. See the\n[`Upgrade from NervesFirmwareSSH`](https://hexdocs.pm/nerves_ssh/readme.html#upgrade-from-nervesfirmwaressh)\ndoc for more details on how to handle this change.","ref":"changelog.html#v0-4-0"},{"type":"extras","title":"v0.3.3 - Changelog","doc":"This allows `v0.9` of the `vintage_net*` libraries.\n\nIf you wish to update the `vintage_net*` libraries, be sure to look at\nthe [VintageNet `v0.9.0` Changelog](https://hexdocs.pm/vintage_net/changelog.html#v0-9-0)\nas there are a few breaking changes that might need to be considered.","ref":"changelog.html#v0-3-3"},{"type":"extras","title":"v0.3.2 - Changelog","doc":"* Enhancements\n  * Update ssh daemon to start with inet6\n\n* Fixes\n  * Remove automatic network configuration - This would interfere with\n  predictable networking support and also made it impossible to deconfigure\n  a network interface permanently","ref":"changelog.html#v0-3-2"},{"type":"extras","title":"v0.3.1 - Changelog","doc":"Few dependency and documentation updates.\n\nThere was a breaking change in `vintage_net 0.8` for anyone implementing a\ncustom technology. This doesn't affect most `nerves_pack` users except that\nthe dependency here on `vintage_net` allows `0.8` along with `0.7`.","ref":"changelog.html#v0-3-1"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"This release removes the `vintage_net_wizard` setup helper. It turned out that\nthere was enough custom configuration that it was easier to configure the WiFi\nwizard on its own rather than via `NervesPack`. If you had been using\n`NervesPack` to configure the wizard, please see the [`vintage_net_wizard`\ndocs](https://hexdocs.pm/vintage_net_wizard).","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"* Enhancements\n  * supervise `sshd` and allow port to be configured\n  * Fix warnings when `vintage_net_wizard` is optional","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"* Enhancements\n  * `:vintage_net_wizard` is now optional and using NervesPack default setup\n    with it requires configuration\n  * removes `:busybox` dependency since that is now included as part of the\n    Nerves systems","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* vintage_net 0.7\n\n* Enhancements\n  * `:vintage_net ~> 0.7` splits out networking technologies into their own\n    libs. Deps have been updated to use this\n  * `WiFiWizardButton` is now an opt-in so that `:circuits_gpio` can be a\n    optional dependency to allow `NervesPack` to work with more systems","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* mdns_lite 0.6.1\n* vintage_net 0.6.6\n\n* Enhancements\n  * With new VintageNet and MdnsLite updates, mDNS host and services can be\n    configured at runtime. This allows us to set basic defaults if no other\n    options have been configured when starting to run\n  * VintageNet and MdnsLite also brings in `VintageNetMonitor` which updates\n    mDNS records whenever address changes happen (polling no longer required).\n    This means faster mDNS response times.","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}